@@ -11,6 +11,8 @@ from airflow.hooks.dbapi import DbApiHook
 from pandas.io.sql import SQLDatabase
 from sqlalchemy import column, insert, select
 
+from astro.dataframes.pandas import PandasDataframe
+
 if TYPE_CHECKING:  # pragma: no cover
     from sqlalchemy.engine.cursor import CursorResult
 from sqlalchemy.sql import ClauseElement
@@ -59,8 +61,8 @@ class BaseDatabase(ABC):
     illegal_column_name_chars: list[str] = []
     illegal_column_name_chars_replacement: list[str] = []
     NATIVE_PATHS: dict[Any, Any] = {}
-    NATIVE_LOAD_EXCEPTIONS: Any = DatabaseCustomError
     DEFAULT_SCHEMA = SCHEMA
+    NATIVE_LOAD_EXCEPTIONS: Any = DatabaseCustomError
     NATIVE_AUTODETECT_SCHEMA_CONFIG: Mapping[FileLocation, Mapping[str, list[FileType] | Callable]] = {}
     FILE_PATTERN_BASED_AUTODETECT_SCHEMA_SUPPORTED: set[FileLocation] = set()
 
@@ -358,7 +360,7 @@ class BaseDatabase(ABC):
         is_file_pattern_based_schema_autodetection_supported = (
             self.check_file_pattern_based_schema_autodetection_is_supported(source_file=file)
         )
-        if if_exists == "replace":
+        if self.schema_exists(table.metadata.schema) and if_exists == "replace":
             self.drop_table(table)
         if use_native_support and is_schema_autodetection_supported and not file.is_pattern():
             return
@@ -475,6 +477,7 @@ class BaseDatabase(ABC):
         if_exists: LoadExistStrategy = "replace",
         chunk_size: int = DEFAULT_CHUNK_SIZE,
     ):
+        logging.info("Loading file(s) with Pandas...")
         input_files = resolve_file_path_pattern(
             input_file.path,
             input_file.conn_id,
@@ -514,6 +517,7 @@ class BaseDatabase(ABC):
         """
 
         try:
+            logging.info("Loading file(s) with Native Support...")
             self.load_file_to_table_natively(
                 source_file=source_file,
                 target_table=target_table,
@@ -521,13 +525,13 @@ class BaseDatabase(ABC):
                 native_support_kwargs=native_support_kwargs,
                 **kwargs,
             )
-        # Catching NATIVE_LOAD_EXCEPTIONS for fallback
         except self.NATIVE_LOAD_EXCEPTIONS as load_exception:  # skipcq: PYL-W0703
             logging.warning(
-                "Loading files failed with Native Support. Falling back to Pandas-based load",
+                "Loading file(s) failed with Native Support.",
                 exc_info=True,
             )
             if enable_native_fallback:
+                logging.warning("Falling back to Pandas-based load...")
                 self.load_file_to_table_using_pandas(
                     input_file=source_file,
                     output_table=target_table,
@@ -646,7 +650,8 @@ class BaseDatabase(ABC):
 
         if self.table_exists(source_table):
             sqla_table = self.get_sqla_table(source_table)
-            return pd.read_sql(sql=sqla_table.select(**select_kwargs), con=self.sqlalchemy_engine)
+            df = pd.read_sql(sql=sqla_table.select(**select_kwargs), con=self.sqlalchemy_engine)
+            return PandasDataframe.from_pandas_df(df)
 
         table_qualified_name = self.get_table_qualified_name(source_table)
         raise NonExistentTableException(f"The table {table_qualified_name} does not exist")
@@ -674,7 +679,9 @@ class BaseDatabase(ABC):
     # Schema Management
     # ---------------------------------------------------------
 
-    def create_schema_if_needed(self, schema: str | None) -> None:
+    def create_schema_if_needed(
+        self, schema: str | None, location: str | None = None  # skipcq: PYL-W0613
+    ) -> None:
         """
         This function checks if the expected schema exists in the database. If the schema does not exist,
         it will attempt to create it.
@@ -695,6 +702,20 @@ class BaseDatabase(ABC):
         """
         raise NotImplementedError
 
+    def get_schema_region(self, schema: str | None = None) -> str:  # skipcq: PYL-W0613, PYL-R0201
+        """
+        Get region where the schema is created
+        :param schema: namespace
+        :return:
+        """
+        return ""
+
+    def check_same_region(self, table: BaseTable, other_table: BaseTable):  # skipcq: PYL-W0613, PYL-R0201
+        """
+        Check if two tables are from the same database region
+        """
+        return True
+
     # ---------------------------------------------------------
     # Context & Template Rendering methods (Transformations)
     # ---------------------------------------------------------
@@ -806,3 +827,10 @@ class BaseDatabase(ABC):
         https://github.com/OpenLineage/OpenLineage/blob/main/spec/Naming.md
         """
         raise NotImplementedError
+
+    def openlineage_dataset_uri(self, table: BaseTable) -> str:
+        """
+        Returns the open lineage dataset uri as per
+        https://github.com/OpenLineage/OpenLineage/blob/main/spec/Naming.md
+        """
+        raise NotImplementedError
