@@ -10,6 +10,13 @@ except ImportError:
     from airflow.decorators.base import task_decorator_factory
     from airflow.decorators import _TaskDecorator as TaskDecorator
 
+import airflow
+
+if airflow.__version__ >= "2.3":
+    from sqlalchemy.engine.row import LegacyRow as SQLAlcRow
+else:
+    from sqlalchemy.engine.result import RowProxy as SQLAlcRow
+
 from astro import settings
 from astro.exceptions import IllegalLoadToDatabaseException
 from astro.sql.operators.base_decorator import BaseSQLDecoratedOperator
@@ -39,7 +46,8 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
 
         if self.handler:
             response = self.handler(result)
-            if self.response_limit >= 0 and len(response) > self.response_limit:
+            response = [SdkLegacyRow.from_legacy_row(r) if isinstance(r, SQLAlcRow) else r for r in response]
+            if 0 <= self.response_limit < len(response):
                 raise IllegalLoadToDatabaseException()  # pragma: no cover
             if self.response_size >= 0:
                 return response[: self.response_size]
@@ -49,6 +57,21 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
             return None
 
 
+class SdkLegacyRow(SQLAlcRow):
+    version: int = 1
+
+    def serialize(self):
+        return {"key_map": self._keymap, "key_style": self._key_style, "data": self._data}
+
+    @staticmethod
+    def deserialize(data: dict, version: int):  # skipcq: PYL-W0613
+        return SdkLegacyRow(None, None, data["key_map"], data["key_style"], data["data"])
+
+    @staticmethod
+    def from_legacy_row(obj):
+        return SdkLegacyRow(None, None, obj._keymap, obj._key_style, obj._data)  # skipcq: PYL-W0212
+
+
 def run_raw_sql(
     python_callable: Callable | None = None,
     conn_id: str = "",
